@@ -7,15 +7,15 @@ from yarl import URL
 
 
 @dataclass(frozen=True)
-class ExtraStorageConfig:
-    path: str
+class VolumeConfig:
     size_mb: int
+    path: Optional[str] = None
 
 
 @dataclass(frozen=True)
 class StorageConfig:
     url: URL
-    extra_storage: Sequence[ExtraStorageConfig] = ()
+    volumes: Sequence[VolumeConfig] = ()
 
 
 @dataclass(frozen=True)
